@@ -154,7 +154,7 @@ Attribute* Attribute::Next( bool throwIfNoAttribute ) const
 	}
 
 	Attribute* temp = new Attribute( attribute );
-	m_spawnedWrappers.push_back( temp );
+	attribute->m_spawnedWrappers.push_back( temp );
 
 	return temp;
 }
@@ -176,7 +176,7 @@ Attribute* Attribute::Previous( bool throwIfNoAttribute ) const
 	}
 
 	Attribute* temp = new Attribute( attribute );
-	m_spawnedWrappers.push_back( temp );
+	attribute->m_spawnedWrappers.push_back( temp );
 
 	return temp;
 }
@@ -252,7 +252,7 @@ Node* Node::NodeFactory( TiXmlNode* tiXmlNode, bool throwIfNull, bool rememberSp
 
 	if ( rememberSpawnedWrapper )
 	{
-		m_spawnedWrappers.push_back( temp );
+		tiXmlNode->m_spawnedWrappers.push_back( temp );
 	}
 	return temp;
 }
@@ -376,9 +376,6 @@ Node* Node::InsertEndChild( Node& addThis )
 		TICPPTHROW( "Node is a Document and can't be inserted" );
 	}
 
-	// Increment reference count when adding to the tree
-	addThis.m_impRC->IncRef();
-
 	TiXmlNode* pointer = GetTiXmlPointer()->InsertEndChild( *addThis.GetTiXmlPointer() );
 	if ( 0 == pointer )
 	{
@@ -566,7 +563,7 @@ Element* Node::NextSiblingElement( const char* value, bool throwIfNoSiblings ) c
 	}
 
 	Element* temp = new Element( sibling );
-	m_spawnedWrappers.push_back( temp );
+	sibling->m_spawnedWrappers.push_back( temp );
 
 	return temp;
 }
@@ -606,7 +603,7 @@ Element* Node::FirstChildElement( const char* value, bool throwIfNoChildren ) co
 	}
 
 	Element* temp = new Element( element );
-	m_spawnedWrappers.push_back( temp );
+	element->m_spawnedWrappers.push_back( temp );
 
 	return temp;
 }
@@ -631,7 +628,7 @@ Document* Node::GetDocument( bool throwIfNoDocument ) const
 		}
 	}
 	Document* temp = new Document( doc );
-	m_spawnedWrappers.push_back( temp );
+	doc->m_spawnedWrappers.push_back( temp );
 
 	return temp;
 }
@@ -649,7 +646,7 @@ Document* Node::ToDocument() const
 		TICPPTHROW( "This node (" << Value() << ") is not a Document" )
 	}
 	Document* temp = new Document( doc );
-	m_spawnedWrappers.push_back( temp );
+	doc->m_spawnedWrappers.push_back( temp );
 
 	return temp;
 }
@@ -662,7 +659,7 @@ Element* Node::ToElement() const
 		TICPPTHROW( "This node (" << Value() << ") is not a Element" )
 	}
 	Element* temp = new Element( doc );
-	m_spawnedWrappers.push_back( temp );
+	doc->m_spawnedWrappers.push_back( temp );
 
 	return temp;
 }
@@ -675,7 +672,7 @@ Comment* Node::ToComment() const
 		TICPPTHROW( "This node (" << Value() << ") is not a Comment" )
 	}
 	Comment* temp = new Comment( doc );
-	m_spawnedWrappers.push_back( temp );
+	doc->m_spawnedWrappers.push_back( temp );
 
 	return temp;
 }
@@ -688,7 +685,7 @@ Text* Node::ToText() const
 		TICPPTHROW( "This node (" << Value() << ") is not a Text" )
 	}
 	Text* temp = new Text( doc );
-	m_spawnedWrappers.push_back( temp );
+	doc->m_spawnedWrappers.push_back( temp );
 
 	return temp;
 }
@@ -701,7 +698,7 @@ Declaration* Node::ToDeclaration() const
 		TICPPTHROW( "This node (" << Value() << ") is not a Declaration" )
 	}
 	Declaration* temp = new Declaration( doc );
-	m_spawnedWrappers.push_back( temp );
+	doc->m_spawnedWrappers.push_back( temp );
 
 	return temp;
 }
@@ -714,7 +711,7 @@ StylesheetReference* Node::ToStylesheetReference() const
 		TICPPTHROW( "This node (" << Value() << ") is not a StylesheetReference" )
 	}
 	StylesheetReference* temp = new StylesheetReference( doc );
-	m_spawnedWrappers.push_back( temp );
+	doc->m_spawnedWrappers.push_back( temp );
 
 	return temp;
 }
@@ -850,7 +847,7 @@ void Document::Parse( const std::string& xml, bool throwIfParseError, TiXmlEncod
 	m_tiXmlPointer->Parse( xml.c_str(), 0, encoding );
 	if( throwIfParseError && m_tiXmlPointer->Error() )
 	{
-		TICPPTHROW( "Error parsing xml: " << m_tiXmlPointer->ErrorDesc() );
+		TICPPTHROW( "Error parsing xml." );
 	}
 }
 
@@ -901,7 +898,7 @@ Attribute* Element::FirstAttribute( bool throwIfNoAttributes ) const
 	}
 
 	Attribute* temp = new Attribute( attribute );
-	m_spawnedWrappers.push_back( temp );
+	attribute->m_spawnedWrappers.push_back( temp );
 
 	return temp;
 }
@@ -928,7 +925,7 @@ Attribute* Element::LastAttribute( bool throwIfNoAttributes ) const
 	}
 
 	Attribute* temp = new Attribute( attribute );
-	m_spawnedWrappers.push_back( temp );
+	attribute->m_spawnedWrappers.push_back( temp );
 
 	return temp;
 }
@@ -948,6 +945,18 @@ std::string Element::GetAttribute( const std::string& name ) const
 	return GetAttributeOrDefault( name, std::string() );
 }
 
+bool Element::HasAttribute( const std::string& name ) const
+{
+	ValidatePointer();
+	return ( 0 != m_tiXmlPointer->Attribute( name.c_str() ) );
+}
+
+void Element::RemoveAttribute( const std::string& name )
+{
+	ValidatePointer();
+	m_tiXmlPointer->RemoveAttribute( name.c_str() );
+}
+
 bool Element::GetAttributeImp( const std::string& name, std::string* value ) const
 {
 	ValidatePointer();
@@ -1075,8 +1084,20 @@ TiCppRC::TiCppRC()
 	m_tiRC = new TiCppRCImp( this );
 }
 
-TiCppRC::~TiCppRC()
+void TiCppRC::DeleteSpawnedWrappers()
 {
+	std::vector< Base* >::reverse_iterator wrapper;
+	for ( wrapper = m_spawnedWrappers.rbegin(); wrapper != m_spawnedWrappers.rend(); ++wrapper )
+	{
+		delete *wrapper;
+	}
+	m_spawnedWrappers.clear();
+}
+		
+TiCppRC::~TiCppRC()
+{	
+	DeleteSpawnedWrappers();
+	
 	// Set pointer held by reference counter to NULL
 	this->m_tiRC->Nullify();
 
