@@ -656,13 +656,43 @@ bool CppCodeGenerator::GenerateCode( PObjectBase project )
 		GenDefines( project );
 	}
 
+    wxString eventHandlerKind;
+	wxString eventHandlerPrefix;
+	wxString eventHandlerPostfix;
+	PProperty eventHandlerKindProp = project->GetProperty( wxT("event_handler") );
+	if ( eventHandlerKindProp )
+	{
+		eventHandlerKind = eventHandlerKindProp->GetValueAsString();
+	}
+
+    if (0 == eventHandlerKind.compare( wxT("decl_pure_virtual") ) )
+    {
+        eventHandlerPrefix = wxT("virtual ");
+        eventHandlerPostfix = wxT(" = 0;");
+    }
+    else if ( 0 == eventHandlerKind.compare( wxT("decl_virtual") ) )
+    {
+        eventHandlerPrefix = wxT("virtual ");
+        eventHandlerPostfix = wxT(";");
+    }
+    else if ( 0 == eventHandlerKind.compare( wxT("decl") ) )
+    {
+        eventHandlerPrefix = wxT("");
+        eventHandlerPostfix = wxT(";");
+    }
+    else // Default: impl_virtual
+    {
+        eventHandlerPrefix = wxT("virtual ");
+        eventHandlerPostfix = wxT(" { event.Skip(); }");
+    }
+
 	for ( unsigned int i = 0; i < project->GetChildCount(); i++ )
 	{
 		PObjectBase child = project->GetChild( i );
 
 		EventVector events;
 		FindEventHandlers( child, events );
-		GenClassDeclaration( child, useEnum, classDecoration, events );
+		GenClassDeclaration( child, useEnum, classDecoration, events, eventHandlerPrefix, eventHandlerPostfix );
 		if ( !m_useConnect )
 		{
 			GenEvents( child, events );
@@ -824,7 +854,7 @@ void CppCodeGenerator::GenPrivateEventHandlers( const EventVector& events )
 	}
 }
 
-void CppCodeGenerator::GenVirtualEventHandlers( const EventVector& events )
+void CppCodeGenerator::GenVirtualEventHandlers( const EventVector& events, const wxString& eventHandlerPrefix, const wxString& eventHandlerPostfix )
 {
 	if ( events.size() > 0 )
 	{
@@ -839,8 +869,8 @@ void CppCodeGenerator::GenVirtualEventHandlers( const EventVector& events )
 		for ( size_t i = 0; i < events.size(); i++ )
 		{
 			PEvent event = events[i];
-			wxString aux = wxT("virtual void ") + event->GetValue() + wxT("( ") +
-				event->GetEventInfo()->GetEventClassName() + wxT("& event ){ event.Skip(); }");
+			wxString aux = eventHandlerPrefix + wxT("void ") + event->GetValue() + wxT("( ") +
+				event->GetEventInfo()->GetEventClassName() + wxT("& event )") + eventHandlerPostfix;
 
 			if (generatedHandlers.find(aux) == generatedHandlers.end())
 			{
@@ -877,6 +907,47 @@ void CppCodeGenerator::GenAttributeDeclaration(PObjectBase obj, Permission perm)
 		GenAttributeDeclaration(child,perm);
 	}
 }
+void CppCodeGenerator::GenValidatorVariables( PObjectBase obj)
+{
+    GenValVarsBase(obj->GetObjectInfo(), obj);
+
+    // Proceeding recursively with the children
+    for (unsigned int i = 0; i < obj->GetChildCount() ; i++)
+    {
+        PObjectBase child = obj->GetChild(i);
+        GenValidatorVariables(child);
+    }
+}
+
+void CppCodeGenerator::GenValVarsBase( PObjectInfo info, PObjectBase obj)
+{
+	wxString _template;
+	PCodeInfo code_info = info->GetCodeInfo( wxT("C++") );
+
+	if ( !code_info )
+	{
+		return;
+	}
+
+	_template = code_info->GetTemplate( wxT("valvar_declaration") );
+
+	if ( !_template.empty() )
+	{
+		CppTemplateParser parser( obj, _template, m_i18n, m_useRelativePath, m_basePath );
+		wxString code = parser.ParseTemplate();
+		if ( !code.empty() )
+		{
+			m_header->WriteLn(code);
+		}
+	}
+
+    // Proceeding recursively with the base classes
+    for (unsigned int i=0; i< info->GetBaseClassCount(); i++)
+    {
+        PObjectInfo base_info = info->GetBaseClass(i);
+        GenValVarsBase(base_info, obj);
+    }
+}
 
 void CppCodeGenerator::GetGenEventHandlers( PObjectBase obj )
 {
@@ -925,7 +996,7 @@ wxString CppCodeGenerator::GetCode(PObjectBase obj, wxString name)
 	return code;
 }
 
-void CppCodeGenerator::GenClassDeclaration(PObjectBase class_obj, bool use_enum, const wxString& classDecoration, const EventVector &events)
+void CppCodeGenerator::GenClassDeclaration(PObjectBase class_obj, bool use_enum, const wxString& classDecoration, const EventVector &events, const wxString& eventHandlerPrefix, const wxString& eventHandlerPostfix)
 {
 	PProperty propName = class_obj->GetProperty( wxT("name") );
 	if ( !propName )
@@ -977,7 +1048,7 @@ void CppCodeGenerator::GenClassDeclaration(PObjectBase class_obj, bool use_enum,
 		GenEnumIds(class_obj);
 
 	GenAttributeDeclaration(class_obj,P_PROTECTED);
-	GenVirtualEventHandlers(events);
+	GenVirtualEventHandlers(events, eventHandlerPrefix, eventHandlerPostfix);
 
 	m_header->Unindent();
 	m_header->WriteLn( wxT("") );
@@ -987,6 +1058,10 @@ void CppCodeGenerator::GenClassDeclaration(PObjectBase class_obj, bool use_enum,
 	m_header->Indent();
 	GenAttributeDeclaration(class_obj,P_PUBLIC);
 
+	// Validators' variables
+	GenValidatorVariables(class_obj);
+	m_header->WriteLn( wxT("") );
+
 	// The constructor is also included within public
 	m_header->WriteLn( GetCode( class_obj, wxT("cons_decl") ) );
 
