@@ -513,6 +513,17 @@ void MainFrame::OnSaveAsProject( wxCommandEvent & )
 			filename = file.GetFullPath();
 		}
 
+		// Check the file whether exists or not
+		if ( file.FileExists() == true )
+		{
+		    wxMessageDialog msg_box( this, wxT("The file already exists. Do you want to replace it?"), wxT("Overwrite the file"), wxYES_NO|wxICON_INFORMATION|wxNO_DEFAULT );
+		    if( msg_box.ShowModal() == wxID_NO )
+			{
+		        dialog->Destroy();
+		        return;
+		    }
+		}
+
 		try
 		{
 			AppData()->SaveProject( filename );
@@ -916,7 +927,7 @@ void MainFrame::UpdateFrame()
 		file = fn.GetName();
 	}
 
-	SetTitle( wxString::Format( wxT("%s%s - wxFormBuilder v3.0"), AppData()->IsModified() ? wxT("*") : wxT(""), file.c_str() ) );
+	SetTitle( wxString::Format( wxT("%s%s - wxFormBuilder v3.1 - Beta"), AppData()->IsModified() ? wxT("*") : wxT(""), file.c_str() ) );
 	GetStatusBar()->SetStatusText( filename, STATUS_FIELD_PATH );
 
 	// Enable/Disable toolbar and menu entries
